package VMOMI::AffinityType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
